<div align='center'>

<img src='https://raw.githubusercontent.com/victorycrest/llmbox/main/logo/llmbox_1024.png' width='20%'>
<h1>LLM Box</h1>
<i>LLMs at your service</i>

<br>
<br>

[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg?logo=apache)](https://github.com/victorycrest/llmbox/blob/master/LICENSE)
[![GitHub](https://img.shields.io/github/stars/victorycrest/llmbox?color=yellowgreen&logo=github)](https://img.shields.io/github/stars/victorycrest/llmbox?color=yellowgreen&logo=github)
[![Twitter](https://img.shields.io/twitter/follow/victorycrest)](https://twitter.com/victorycrest)

[![PyPI Version](https://img.shields.io/pypi/v/llmbox?label=pypi&color=green)](https://pypi.org/project/llmbox)
[![Downloads](https://img.shields.io/pypi/dm/llmbox?color=orange)](https://pypi.org/project/llmbox)
[![Python Version](https://img.shields.io/pypi/pyversions/llmbox?color=yellow)](https://pypi.org/project/llmbox)
[![Docs](https://readthedocs.org/projects/llmbox/badge/?version=latest)](https://llmbox.readthedocs.io/en/latest)

</div>

## Index 📒

* [Mission](#Mission)
* [Applications](#Applications)
* [Credits](#Credits)
* [License](#License)

## Mission 🚀
Large Language Models (LLMs) have taken the world by storm with its endless capabilities and applications.

But we are still in the early days.

LLM Box is a collection of UI-based applications built using open source and/or enterprise LLMs as solutions for simple, fun or complex use cases.

Why code when you don't have to? But ok, there is a Python package too.

## Applications 🖥️

#### Playground
| App                                                                            | Description                                      |
|--------------------------------------------------------------------------------|--------------------------------------------------|
| [Claude Box](https://github.com/victorycrest/llmbox/tree/main/apps/claude_box) | Chat with the Claude family of LLMs by Anthropic |

## Credits 🙏

#### Logo
Generated using [Midjourney](https://www.midjourney.com) with the prompt:

> *Minimalistic vector logo made of lines featuring a fancy box, using simple shapes and lines in a blocky, modern, and artistic style with a color scheme of five colors*

#### LLMs
* [Claude by Anthropic](https://www.anthropic.com/index/introducing-claude)

## License 📋
This project is licensed under the [Apache License 2.0](https://github.com/victorycrest/llmbox/blob/master/LICENSE).
